// Copyright © 2020 Finn Herzfeld <finn@janky.solutions>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

package cmd

import (
	"fmt"
	"log"
	"math/rand"

	"github.com/spf13/cobra"

	"gitlab.com/signald/signald-go/signald/client-protocol/v0"
)

// listGroupsCmd represents the listGroups command
var listGroupsCmd = &cobra.Command{
	Use:   "list-groups",
	Short: "list of all the groups that the user is in.",
	Long:  `Prints a list of all groups the user is in to stdout.`,
	Run: func(cmd *cobra.Command, args []string) {
		requestID := fmt.Sprint("signaldctl-", rand.Intn(1000))
		err := s.RawRequest(v0.LegacyRequest{
			Type:     "list_groups",
			Username: username,
			ID:       requestID,
		})
		if err != nil {
			log.Fatal("error sending request: ", err)
		}

		c := make(chan v0.LegacyResponse)
		go s.Listen(c)
		for {
			message := <-c
			if message.ID == requestID {
				for _, group := range message.Data.Groups {
					fmt.Println(group.Name)
				}
				break
			}
		}
	},
}

func init() {
	RootCmd.AddCommand(listGroupsCmd)

	listGroupsCmd.Flags().StringVarP(&username, "username", "u", "", "The username of the account to use)")
	must(listGroupsCmd.MarkFlagRequired("username"))
}
