// Copyright © 2020 Finn Herzfeld <finn@janky.solutions>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

package cmd

import (
	"encoding/json"
	"fmt"
	"log"
	"math/rand"
	"os"

	"github.com/spf13/cobra"

	"gitlab.com/signald/signald-go/signald/client-protocol/v0"
)

// subscribeCmd represents the subscribe command
var subscribeCmd = &cobra.Command{
	Use:   "subscribe",
	Short: "subscribe to incoming messages",
	Long:  `receive incoming messages from Signal`,
	Run: func(cmd *cobra.Command, args []string) {
		requestID := fmt.Sprint("signaldctl-", rand.Intn(1000))
		err := s.RawRequest(v0.LegacyRequest{
			Type:     "subscribe",
			Username: username,
			ID:       requestID,
		})
		if err != nil {
			log.Fatal("error sending request: ", err)
		}

		c := make(chan v0.LegacyResponse)
		go s.Listen(c)

		go func() {
			defer s.CloseResponseListener(requestID)
			r := <-s.GetResponseListener(requestID)
			if r.GetError() != nil {
				log.Fatal("error subscribing: ", r.GetError())
			}
		}()

		for {
			msg := <-c
			if err := json.NewEncoder(os.Stdout).Encode(msg); err != nil {
				log.Fatal("error encoding response to JSON. this should never happen", err)
			}
		}
	},
}

func init() {
	RootCmd.AddCommand(subscribeCmd)

	subscribeCmd.Flags().StringVarP(&username, "username", "u", "", "The phone number to subscribe to")
	must(subscribeCmd.MarkFlagRequired("username"))
}
