// Copyright © 2020 Finn Herzfeld <finn@janky.solutions>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

package cmd

import (
	"fmt"
	"log"
	"math/rand"

	"github.com/spf13/cobra"

	"gitlab.com/signald/signald-go/signald/client-protocol/v0"
)

var (
	code string
)

// verify represents the verify command
var verify = &cobra.Command{
	Use:   "verify",
	Short: "Verify an account confirmation code and complete account setup",
	Long:  `Verify the phone number on a new account by submitting a verification code, completing the account registration process.`,
	Run: func(cmd *cobra.Command, args []string) {
		requestID := fmt.Sprint("signaldctl-", rand.Intn(1000))
		err := s.RawRequest(v0.LegacyRequest{
			Type:     "verify",
			Username: username,
			Code:     code,
			ID:       requestID,
		})
		if err != nil {
			log.Fatal("error sending request: ", err)
		}
		go s.Listen(nil)

		defer s.CloseResponseListener(requestID)
		r := <-s.GetResponseListener(requestID)
		account, err := r.Data.MarshalJSON()
		if err != nil {
			log.Fatal("error rendering response:", err)
		}
		fmt.Println("account created:", string(account))
	},
}

func init() {
	RootCmd.AddCommand(verify)

	verify.Flags().StringVarP(&username, "username", "u", "", "The phone number the verification code was sent to")
	must(verify.MarkFlagRequired("username"))

	verify.Flags().StringVarP(&code, "code", "c", "", "The verification code")
	must(verify.MarkFlagRequired("code"))
}
