// Copyright © 2018 Finn Herzfeld <finn@janky.solutions>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

package cmd

import (
	"encoding/json"
	"log"
	"os"

	"github.com/spf13/cobra"

	"gitlab.com/signald/signald-go/signald/client-protocol/v1"
)

// versionCmd represents the version command
var versionCmd = &cobra.Command{
	Use:   "version",
	Short: "print the signald version",
	Long:  `print the signald version`,
	Run: func(cmd *cobra.Command, args []string) {
		go s.Listen(nil)
		r := v1.VersionRequest{}
		response, err := r.Submit(s)
		if err != nil {
			log.Fatal(err)
		}
		err = json.NewEncoder(os.Stdout).Encode(response)
		if err != nil {
			log.Fatal("error encoding output ", err)
		}
	},
}

func init() {
	RootCmd.AddCommand(versionCmd)
}
