package v1

// DO NOT EDIT: this file is automatically generated by ./tools/generator in this repo

import (
	"gitlab.com/signald/signald-go/signald/client-protocol/v0"
)

type Request struct {
	ID      string `json:"id"`
	Version string `json:"version"`
	Type    string `json:"type"`
}

// AcceptInvitationRequest: Accept a v2 group invitation. Note that you must have a profile name set to join groups.
type AcceptInvitationRequest struct {
	Request
	Account string `json:"account,omitempty"` // The account to interact with
	GroupID string `json:"groupID,omitempty"`
}

// ApproveMembershipRequest: approve a request to join a group
type ApproveMembershipRequest struct {
	Request
	Account string         `json:"account,omitempty"` // The account to interact with
	GroupID string         `json:"groupID,omitempty"`
	Members []*JsonAddress `json:"members,omitempty"` // list of requesting members to approve
}

type Capabilities struct {
	Gv1Migration bool `json:"gv1-migration,omitempty"`
	Gv2          bool `json:"gv2,omitempty"`
	Storage      bool `json:"storage,omitempty"`
}

// GetGroupRequest: Query the server for the latest state of a known group
type GetGroupRequest struct {
	Request
	Account  string `json:"account,omitempty"` // The account to interact with
	GroupID  string `json:"groupID,omitempty"`
	Revision int32  `json:"revision,omitempty"` // the latest known revision, default value (-1) forces fetch from server
}

// GetLinkedDevicesRequest: list all linked devices on a Signal account
type GetLinkedDevicesRequest struct {
	Request
	Account string `json:"account,omitempty"` // The account to interact with
}

// GetProfileRequest: Get all information available about a user
type GetProfileRequest struct {
	Request
	Account string       `json:"account,omitempty"` // the signald account to use
	Address *JsonAddress `json:"address,omitempty"` // the address to look up
}

// GroupInfo: A generic type that is used when the group version is not known
type GroupInfo struct {
	V1 *JsonGroupInfo   `json:"v1,omitempty"`
	V2 *JsonGroupV2Info `json:"v2,omitempty"`
}

// JoinGroupRequest: Join a group using the a signal.group URL. Note that you must have a profile name set to join groups.
type JoinGroupRequest struct {
	Request
	Account string `json:"account,omitempty"` // The account to interact with
	Uri     string `json:"uri,omitempty"`     // The signal.group URL
}

type JsonAddress struct {
	Number string `json:"number,omitempty"` // An e164 phone number, starting with +. Currently the only available user-facing Signal identifier.
	Relay  string `json:"relay,omitempty"`
	UUID   string `json:"uuid,omitempty"` // A UUID, the unique identifier for a particular Signal account.
}

type JsonBlockedListMessage struct {
	Addresses []*JsonAddress `json:"addresses,omitempty"`
	GroupIds  []string       `json:"groupIds,omitempty"`
}

type JsonDataMessage struct {
	Attachments      []*v0.JsonAttachment `json:"attachments,omitempty"` // files attached to the incoming message
	Body             string               `json:"body,omitempty"`        // the text body of the incoming message.
	Contacts         []*v0.SharedContact  `json:"contacts,omitempty"`    // if the incoming message has a shared contact, the contact's information will be here
	EndSession       bool                 `json:"endSession,omitempty"`
	ExpiresInSeconds int32                `json:"expiresInSeconds,omitempty"` // the expiry timer on the incoming message. Clients should delete records of the message within this number of seconds
	Group            *JsonGroupInfo       `json:"group,omitempty"`            // if the incoming message was sent to a v1 group, information about that group will be here
	GroupV2          *JsonGroupV2Info     `json:"groupV2,omitempty"`          // is the incoming message was sent to a v2 group, basic identifying information about that group will be here. For full information, use list_groups
	Mentions         []*JsonMention       `json:"mentions,omitempty"`         // list of mentions in the message
	Previews         []*v0.JsonPreview    `json:"previews,omitempty"`         // if the incoming message has a link preview, information about that preview will be here
	ProfileKeyUpdate bool                 `json:"profileKeyUpdate,omitempty"`
	Quote            *JsonQuote           `json:"quote,omitempty"`        // if the incoming message is a quote or reply to another message, this will contain information about that message
	Reaction         *JsonReaction        `json:"reaction,omitempty"`     // if the message adds or removes a reaction to another message, this will indicate what change is being made
	RemoteDelete     *v0.RemoteDelete     `json:"remoteDelete,omitempty"` // if the inbound message is deleting a previously sent message, indicates which message should be deleted
	Sticker          *v0.JsonSticker      `json:"sticker,omitempty"`      // if the incoming message is a sticker, information about the sicker will be here
	Timestamp        int64                `json:"timestamp,omitempty"`    // the timestamp that the message was sent at, according to the sender's device. This is used to uniquely identify this message for things like reactions and quotes.
	ViewOnce         bool                 `json:"viewOnce,omitempty"`     // indicates the message is a view once message. View once messages typically include no body and a single image attachment. Official Signal clients will prevent the user from saving the image, and once the user has viewed the image once they will destroy the image.
}

type JsonGroupInfo struct {
	AvatarId int64          `json:"avatarId,omitempty"`
	GroupId  string         `json:"groupId,omitempty"`
	Members  []*JsonAddress `json:"members,omitempty"`
	Name     string         `json:"name,omitempty"`
	Type     string         `json:"type,omitempty"`
}

type JsonGroupJoinInfo struct {
	AddFromInviteLink    int32  `json:"addFromInviteLink,omitempty"`
	GroupID              string `json:"groupID,omitempty"`
	MemberCount          int32  `json:"memberCount,omitempty"`
	PendingAdminApproval bool   `json:"pendingAdminApproval,omitempty"`
	Revision             int32  `json:"revision,omitempty"`
	Title                string `json:"title,omitempty"`
}

type JsonGroupV2Info struct {
	ID                string         `json:"id,omitempty"`
	InviteLink        string         `json:"inviteLink,omitempty"`
	Members           []*JsonAddress `json:"members,omitempty"`
	PendingMembers    []*JsonAddress `json:"pendingMembers,omitempty"`
	RequestingMembers []*JsonAddress `json:"requestingMembers,omitempty"`
	Revision          int32          `json:"revision,omitempty"`
	Timer             int32          `json:"timer,omitempty"`
	Title             string         `json:"title,omitempty"`
}

type JsonMention struct {
	Length int32  `json:"length,omitempty"` // The length of the mention represented in the message. Seems to always be 1 but included here in case that changes.
	Start  int32  `json:"start,omitempty"`  // The number of characters in that the mention starts at. Note that due to a quirk of how signald encodes JSON, if this value is 0 (for example if the first character in the message is the mention) the field won't show up.
	UUID   string `json:"uuid,omitempty"`   // The UUID of the account being mentioned
}

type JsonMessageEnvelope struct {
	CallMessage              *v0.JsonCallMessage    `json:"callMessage,omitempty"`
	DataMessage              *JsonDataMessage       `json:"dataMessage,omitempty"`
	HasContent               bool                   `json:"hasContent,omitempty"`
	HasLegacyMessage         bool                   `json:"hasLegacyMessage,omitempty"`
	IsUnidentifiedSender     bool                   `json:"isUnidentifiedSender,omitempty"`
	Receipt                  *v0.JsonReceiptMessage `json:"receipt,omitempty"`
	Relay                    string                 `json:"relay,omitempty"`
	ServerDeliveredTimestamp int64                  `json:"serverDeliveredTimestamp,omitempty"`
	ServerTimestamp          int64                  `json:"serverTimestamp,omitempty"`
	Source                   *JsonAddress           `json:"source,omitempty"`
	SourceDevice             int32                  `json:"sourceDevice,omitempty"`
	SyncMessage              *JsonSyncMessage       `json:"syncMessage,omitempty"`
	Timestamp                int64                  `json:"timestamp,omitempty"`
	TimestampISO             string                 `json:"timestampISO,omitempty"`
	Type                     string                 `json:"type,omitempty"`
	Typing                   *v0.JsonTypingMessage  `json:"typing,omitempty"`
	Username                 string                 `json:"username,omitempty"`
	UUID                     string                 `json:"uuid,omitempty"`
}

type JsonMessageRequestResponseMessage struct {
	GroupId string       `json:"groupId,omitempty"`
	Person  *JsonAddress `json:"person,omitempty"`
	Type    string       `json:"type,omitempty"`
}

// JsonQuote: A quote is a reply to a previous message. ID is the sent time of the message being replied to
type JsonQuote struct {
	Attachments []*v0.JsonQuotedAttachment `json:"attachments,omitempty"` // list of files attached to the quoted message
	Author      *JsonAddress               `json:"author,omitempty"`      // the author of the message being quoted
	ID          int64                      `json:"id,omitempty"`          // the client timestamp of the message being quoted
	Mentions    []*JsonMention             `json:"mentions,omitempty"`    // list of mentions in the quoted message
	Text        string                     `json:"text,omitempty"`        // the body of the message being quoted
}

type JsonReaction struct {
	Emoji               string       `json:"emoji,omitempty"`               // the emoji to react with
	Remove              bool         `json:"remove,omitempty"`              // set to true to remove the reaction. requires emoji be set to previously reacted emoji
	TargetAuthor        *JsonAddress `json:"targetAuthor,omitempty"`        // the author of the message being reacted to
	TargetSentTimestamp int64        `json:"targetSentTimestamp,omitempty"` // the client timestamp of the message being reacted to
}

type JsonReadMessage struct {
	Sender    *JsonAddress `json:"sender,omitempty"`
	Timestamp int64        `json:"timestamp,omitempty"`
}

type JsonSendMessageResult struct {
	Address             *JsonAddress `json:"address,omitempty"`
	IdentityFailure     string       `json:"identityFailure,omitempty"`
	NetworkFailure      bool         `json:"networkFailure,omitempty"`
	Success             *v0.Success  `json:"success,omitempty"`
	UnregisteredFailure bool         `json:"unregisteredFailure,omitempty"`
}

type JsonSentTranscriptMessage struct {
	Destination              *JsonAddress      `json:"destination,omitempty"`
	ExpirationStartTimestamp int64             `json:"expirationStartTimestamp,omitempty"`
	IsRecipientUpdate        bool              `json:"isRecipientUpdate,omitempty"`
	Message                  *JsonDataMessage  `json:"message,omitempty"`
	Timestamp                int64             `json:"timestamp,omitempty"`
	UnidentifiedStatus       map[string]string `json:"unidentifiedStatus,omitempty"`
}

type JsonSyncMessage struct {
	BlockedList            *JsonBlockedListMessage               `json:"blockedList,omitempty"`
	Configuration          *v0.ConfigurationMessage              `json:"configuration,omitempty"`
	Contacts               *v0.JsonAttachment                    `json:"contacts,omitempty"`
	ContactsComplete       bool                                  `json:"contactsComplete,omitempty"`
	FetchType              string                                `json:"fetchType,omitempty"`
	Groups                 *v0.JsonAttachment                    `json:"groups,omitempty"`
	MessageRequestResponse *JsonMessageRequestResponseMessage    `json:"messageRequestResponse,omitempty"`
	ReadMessages           []*JsonReadMessage                    `json:"readMessages,omitempty"`
	Request                string                                `json:"request,omitempty"`
	Sent                   *JsonSentTranscriptMessage            `json:"sent,omitempty"`
	StickerPackOperations  []*v0.JsonStickerPackOperationMessage `json:"stickerPackOperations,omitempty"`
	Verified               *JsonVerifiedMessage                  `json:"verified,omitempty"`
	ViewOnceOpen           *JsonViewOnceOpenMessage              `json:"viewOnceOpen,omitempty"`
}

type JsonVerifiedMessage struct {
	Destination *JsonAddress `json:"destination,omitempty"`
	IdentityKey string       `json:"identityKey,omitempty"`
	Timestamp   int64        `json:"timestamp,omitempty"`
	Verified    string       `json:"verified,omitempty"`
}

type JsonVersionMessage struct {
	Branch  string `json:"branch,omitempty"`
	Commit  string `json:"commit,omitempty"`
	Name    string `json:"name,omitempty"`
	Version string `json:"version,omitempty"`
}

type JsonViewOnceOpenMessage struct {
	Sender    *JsonAddress `json:"sender,omitempty"`
	Timestamp int64        `json:"timestamp,omitempty"`
}

type LinkedDevices struct {
	Devices []*v0.DeviceInfo `json:"devices,omitempty"`
}

type MarkReadRequest struct {
	Request
	Account    string       `json:"account,omitempty"`    // The account to interact with
	Timestamps []int64      `json:"timestamps,omitempty"` // List of messages to mark as read
	To         *JsonAddress `json:"to,omitempty"`         // The address that sent the message being marked as read
}

// Profile: Information about a Signal user
type Profile struct {
	Address        *JsonAddress  `json:"address,omitempty"`
	Avatar         string        `json:"avatar,omitempty"`
	Capabilities   *Capabilities `json:"capabilities,omitempty"`
	Color          string        `json:"color,omitempty"`
	ExpirationTime int32         `json:"expiration_time,omitempty"`
	InboxPosition  int32         `json:"inbox_position,omitempty"`
	Name           string        `json:"name,omitempty"`         // The user's name from local contact names if available, or if not in contact list their Signal profile name
	ProfileName    string        `json:"profile_name,omitempty"` // The user's Signal profile name
}

type ProtocolRequest struct {
	Request
}

// ReactRequest: react to a previous message
type ReactRequest struct {
	Request
	Reaction         *JsonReaction `json:"reaction,omitempty"`
	RecipientAddress *JsonAddress  `json:"recipientAddress,omitempty"`
	RecipientGroupID string        `json:"recipientGroupId,omitempty"`
	Timestamp        int64         `json:"timestamp,omitempty"`
	Username         string        `json:"username,omitempty"`
}

// RemoveLinkedDeviceRequest: Remove a linked device from the Signal account. Only allowed when the local device id is 1
type RemoveLinkedDeviceRequest struct {
	Request
	Account  string `json:"account,omitempty"`  // The account to interact with
	DeviceId int64  `json:"deviceId,omitempty"` // the ID of the device to unlink
}

// ResolveAddressRequest: Resolve a partial JsonAddress with only a number or UUID to one with both. Anywhere that signald accepts a JsonAddress will except a partial, this is a convenience function for client authors, mostly because signald doesn't resolve all the partials it returns
type ResolveAddressRequest struct {
	Request
	Account string       `json:"account,omitempty"` // The signal account to use
	Partial *JsonAddress `json:"partial,omitempty"` // The partial address, missing fields
}

type SendRequest struct {
	Request
	Attachments      []*v0.JsonAttachment `json:"attachments,omitempty"`
	Mentions         []*JsonMention       `json:"mentions,omitempty"`
	MessageBody      string               `json:"messageBody,omitempty"`
	Quote            *JsonQuote           `json:"quote,omitempty"`
	RecipientAddress *JsonAddress         `json:"recipientAddress,omitempty"`
	RecipientGroupID string               `json:"recipientGroupId,omitempty"`
	Timestamp        int64                `json:"timestamp,omitempty"`
	Username         string               `json:"username,omitempty"`
}

type SendResponse struct {
	Results   []*JsonSendMessageResult `json:"results,omitempty"`
	Timestamp int64                    `json:"timestamp,omitempty"`
}

type SetProfile struct {
	Request
	Account    string `json:"account,omitempty"`    // The phone number of the account to use
	AvatarFile string `json:"avatarFile,omitempty"` // Path to new profile avatar file, if the avatar should be updated
	Name       string `json:"name,omitempty"`       // New profile name. Set to empty string for no profile name
}

// UpdateGroupRequest: modify a group
type UpdateGroupRequest struct {
	Request
	Account       string         `json:"account,omitempty"` // The identifier of the account to interact with
	AddMembers    []*JsonAddress `json:"addMembers,omitempty"`
	Avatar        string         `json:"avatar,omitempty"`
	GroupID       string         `json:"groupID,omitempty"`
	RemoveMembers []*JsonAddress `json:"removeMembers,omitempty"`
	Title         string         `json:"title,omitempty"`
}

type VersionRequest struct {
	Request
}
